#
# spec file for package workrave
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upstream_version    1_10_50
Name:           workrave
Version:        1.10.50
Release:        3.5
Summary:        Recovery and prevention of Repetitive Strain Injury program
License:        GPL-3.0-only
Group:          Productivity/Other
URL:            http://www.workrave.org
Source:         https://github.com/rcaelers/workrave/archive/v%{upstream_version}.tar.gz
Source2:        %{name}-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  libpulse-devel
BuildRequires:  libtool
BuildRequires:  python3-Jinja2
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xtst)

%description
Workrave is a program that assists in the recovery and prevention of Repetitive Strain Injury (RSI). The program frequently alerts you to take micro-pauses, rest breaks and restricts you to your daily limit.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/Other

%description devel
This package contains header files needed for developing plugins for
Workrave.

%package -n typelib-1_0-Workrave-1_0
Summary:        Introspection bindings for Workrave
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n typelib-1_0-Workrave-1_0
This package contains typelib files needed for developing plugins for
Workrave.

%prep
%setup -q -n %{name}-%{upstream_version}

%build
./autogen.sh
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}/%{_libdir} -type f -name "*.la" -delete
%suse_update_desktop_file %{name}
rm -f %{buildroot}/%{_libdir}/libworkrave-private-1.0.so
%fdupes %{buildroot}/%{_prefix}
%find_lang %{name}

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files -f %{name}.lang
%license COPYING
%doc AUTHORS NEWS README.md ABOUT-NLS
%{_bindir}/workrave
%dir %{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/dbus*/*
%dir %{_datadir}/sounds/%{name}
%{_datadir}/sounds/%{name}/*
%{_datadir}/%{name}/*
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/extensions
%dir %{_datadir}/gnome-shell/extensions/workrave@workrave.org
%{_datadir}/gnome-shell/extensions/workrave@workrave.org/*
%if 0%{?suse_version} > 1140
%{_datadir}/glib-2.0/schemas/org.workrave.enums.xml
%{_datadir}/glib-2.0/schemas/org.workrave.gschema.xml
%{_datadir}/glib-2.0/schemas/org.workrave.gui.gschema.xml
%else
%{_libdir}/bonobo/servers/Workrave-Applet.server
%{_datadir}/gnome-2.0/ui/GNOME_WorkraveApplet.xml
%endif
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/workrave.appdata.xml
%{_datadir}/cinnamon/applets/workrave@workrave.org/applet.js
%{_datadir}/cinnamon/applets/workrave@workrave.org/metadata.json
%dir /usr/share/cinnamon/
%dir /usr/share/cinnamon/applets/
%dir /usr/share/cinnamon/applets/workrave@workrave.org/
%{_libdir}/libworkrave-private-*

%files devel
%{_datadir}/gir-1.0/Workrave-1.0.gir

%files -n typelib-1_0-Workrave-1_0
%{_libdir}/girepository-1.0/Workrave-1.0.typelib

%changelog
* Fri Feb  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop obsolete python-xml BuildRequires: python-xml is a python2
  package, but there seems to be no trace of python2 being used in
  any way. Changelog mentioned in 2019 that python2 would not
  longer be required to build. (boo#1219306).
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Resolve xorg-x11-devel BuildRequire to pkgconfig(...)
* Fri Apr  1 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.10.50:
  - The "Restbreak now" button in the main window no longer responds to keyboard (#368)
  - Allow installation on Windows without administrator rights.
  - Fix vertical alignment of GNOME shell applet (#356)
  - Support GNOME Shell 42 (#396)
  - Restore support for Windows Vista and up (#367)
  - The 'Backward shoulder stretch' exercises now plays a sound twice matching the description (#354)
- remove obsolete gnome42.patch
- remove obsolete gnome42-vertical-alignment.patch
- remove obsolete gnome42-fixapplet.patch
* Thu Mar 31 2022 Timo Jyrinki <tjyrinki@suse.com>
- Add patches for GNOME 42 from upstream (boo#1197808):
  - gnome42.patch
  - gnome42-vertical-alignment.patch
  - gnome42-fixapplet.patch
* Wed Jan  5 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.10.49
  - Adds support for GNOME Shell 41 (#342, Timo Jyrinki)
  - Inno Setup improvement (#353, Kaleb Luedtke)
* Sun Aug 15 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove obsolete fix-wayland-gnome-crash.patch
- remove obsolete support-gnome-40.patch
* Sun Aug  8 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.10.48:
  - Fixed GNOME Shell applet on Ubuntu 18.04 (#281)
- update to version 1.10.47:
  - Fixed a crash of the GNOME Shell applet (#281)
  - Adds support for GNOME Shell 40 (#288)
  - Fixed issue where the installer would fail when installing as system user
  (#291)
  - Fixed incorrect disabling of postpone/skip button (#301)
  - Warn if operation mode is not 'normal' after unlocking the screen (Windows
  only for now)
* Thu Jun  3 2021 Timo Jyrinki <tjyrinki@suse.com>
- Add back the removed patches that were not included yet in the latest
  upstream release that was done already in March.
  - Add fix-wayland-gnome-crash.patch, now not needing rebasing
  - Add support-gnome-40.patch
* Mon May 31 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove obsolete fix-wayland-gnome-crash.patch
- remove obsolete support-gnome-40.patch
- Update to version 1.10.45:
  - Micro breaks without a postpone button could be postponed by starting a
  - rest break while the break prompt window was visible and then clicking
  - postpone in the rest break window. The postpone button is now disabled
  - when the micro break is overdue, and the maximum number of break prompts
  - was reached.
  - A new sound theme calls 'Bells' has been added (#225, Pieter De Decker)
  - Added support for High-DPI displays in the Windows Applet.
  - The Windows applet now correctly enforces a minimum size (#252)
  - Initial support for icon themes.
  - Fixes:
  - Fixed build issue with libayatana-indicator3
  - Fixed issue where Workrave would show 2 status icons on Linux (#258)
  - Fixed a deprecation warning in the Gnome Shell applet (#251)
  - The cinnamon applet is no longer bouncing up and down (#253)
  - Fixed issue where the current language was always "Unrecognized language"
  - Fixed issue where activity monitoring would stop after restarting Gnome Shell
  - Fixed issue that caused the main window to disappear (#244, 259)
  - Translation updates:
  - Updated Chinese translation (#232, wintertee)
  - Updated French translation (Darialalala)
  - Updated Dutch translation (Matthias Huijgen)
  - Fixed typo in the Italian translation (#234, albanobattistella)
* Fri Apr 16 2021 Timo Jyrinki <tjyrinki@suse.com>
- Add support-gnome-40.patch to fix working with GNOME 40
* Thu Apr 15 2021 Timo Jyrinki <tjyrinki@suse.com>
- Add fix-wayland-gnome-crash.patch (boo#1184773).
  * Cherry-pick and rebase a fix from upstream git to fix a GNOME crash.
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.0.44:
  * Update Italian translation (Albano Battistella)
  * Support libayatana-indicator3 (Kentaro Hayashi)
  * Fixed issue on Gnome where Workrave would not detect that the user is idle (#181)
  * Fix issue where a break window could disappear after a few seconds.
  * Fix issie where the Gnome Shell applet would be reload on Ubuntu 18.04.
  * Update Traditional Chinese translation (Yuenfu Chiu)
  * Fix Gnome Shell applet compatibility issue with Ubuntu 18.04.
  * Fix incomplete Gnome Shell applet menu with latest version of Gnome Shell
  * Fix creation for source tarball.
  * When it is time to take a micro break, Workrave may start a rest break
  * instead. This happens when the rest break would start within 30 seconds of
  * the micro break. If the postpone or skip buttons are disabled on the micro
  * break, they will be temporarily disabled on the rest break window. A small
  * progress bar indicates how long the buttons are disabled. Previously,
  * Workrave would restart the micro break when pressing the skip or postpone
  * button.
  * Support applets on Gnome 3.35.1+ using libgnome-panel (Alberts Muktupāvels).
  * Added Indonesian translation (Andika Triwidada).
  * Fixed issue where Workrave was not properly terminated on reinstall.
  * Show operation mode in Gnome applet.
  * Fixed focus issue on rest break window that caused muted (grey) text.
  * Update Irish translation (Seanán Ó Coistín)
  * new Portuguese translation (pmraps)
  * Non-blocking break windows are now centered on Wayland/mutter (#163)
  * Support display scaling
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace glibmm2-devel and libsigc++2-devel with
  pkgconfig(glibmm-2.4) and pkgconfig(sigc++-2.0) BuildRequires:
  align with what configure checks for.
* Thu Jun 13 2019 Timo Jyrinki <tjyrinki@suse.com>
- Add boost-devel build dep, replace python-cheetah with python3-Jinja2
- Update appdata install directory
- update to version 1.10.34:
  - Ubuntu Trusty and Xenial build fixes.
- update to version 1.10.33:
  - Packaging fixes.
- update to version 1.10.32:
  - Fixed a bug that caused high CPU load when the main window was
  open for a long time.
  - [internal change] Python 2 is no longer required for building
  Workrave. The Python2-only Cheetah dependency has been replaced
  by Jinja 2 (python3-jinja2). Additionally, Boost >= 1.52 is now
  required (libboost-dev).
- update to version 1.10.31:
  - Add GetTimerRemaining dbus function.
- update to version 1.10.30:
  - Prevent "Workrave wants to inhibit shortcuts" on Wayland
  - Fix timer bar text color under Wayland
  - Do not dim text in time bar when window is not focused.
- update to version 1.10.28/29:
  - Fix PPA upload
- update to version 1.10.27:
  - Fix menu in Cinnamon applet
  - Fix bouncing Cinnamon applet
- update to version 1.10.26:
  - Fix Gnome Shell applet for Gnome Shell v3.30
  - Reduce padding in timer window
- update to version 1.10.25:
  - Packaging fixes
- update to version 1.10.24:
  - Fix AppStream metadata
  - Update Slovak translation
* Sat Oct 13 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.10.23:
  - no changelog available
- update to version 1.10.22:
  - Fix size of Xfce applet
- update to version 1.10.21:
  - Support MATE applet with Gtk+3
  - Support Xfce applet with Gtk+3
* Tue Apr 17 2018 jengelh@inai.de
- Redo typelib package according to other typelib packages
- Un-SLPP private libraries
- Remove -devel subpackage because there are no headers
* Tue Apr 17 2018 sebix+novell.com@sebix.at
- fix packaging or .a, .la files
- add typelib subpackage
- fix ldconfig calls
* Mon Mar 19 2018 sebix+novell.com@sebix.at
- update to version 1.10.20
  * Fix activity monitoring on non-Gnome desktop environments
  * Workrave 1.10.19
  * Fix crash because of missing setting
  * Fix Gnome Shell applet
- update to version 1.10.18
  * Support Gnome Shell 3.24/26
- update to version 1.10.17
  * Update Czech translation (Pavel Bborecki)
- update to version 1.10.16
  * Mark applet as compatible with GNOME 3.22 (Francois Marier)
  * Fix text alignment time bar.
  * Fix resuming microbreak after postponing restbreak
- update to version 1.10.15
  * Fix crash when no shutdown/hibernate options are available.
  * Updated traditional Chinese translation (Kevin Kuan)
- update to version 1.10.14
  * Fixed issue where pressing the down key during a restbreak would
  lock the screen (bug #1242)
- update to version 1.10.13
  * Use button instead of combobox if only 'Lock' is available in
  restbreak window (pedantic-git)
  * Update german translation (rsnitsch)
  * Support Gnome Shell 3.20 (Francois Marier)
- update to version 1.10.12
  * Updated Catalan translation (Jordi Mallach)
  * Fixed Gnome Shell applet (Amir Mohammadi)
- update to version 1.10.11
  * Improved security of network protocol.
  NOTE: this is a backward incompatible change.
  This version of Workrave will no longer connect to older Workrave versions.
  * Minor improvements
- update to version 1.10.9
  * UI tweak
- update to version 1.10.8
  * Extra statistics
  - Weekly usage statistics (Rob Caelers)
  - Monthly usage statistics (Denis Nikolaenko)
  * Fix gtkmm 3.18 compilation (Javier Tia, Denis Nikolaenko)
  * Support Gnome 3.16
- update to version 1.10.7
  * Update translations:
  - Spanish (Fco. Javier Serrador)
- update to version 1.10.6
  * Improved screen lock and shutdown in break window (Mateusz Jończyk)
  * Add suspend/hibernate option to break window on Linux (Mateusz Jończyk)
  * Gnome applet updated to work with latest Gnome 3 flashback (Dmitry Shachnev)
  * Applets added for Cinnamon, XFCE and MATE.
  * Bug fixes:
  - Break window was transparent when blocking mode was set to 'input and screen'
  - Text background in exercises window was black, making the text unreadable.
  - In some cases the timers were shown twice in the panel
- update to version 1.10.5
  * Updated tranlations:
  - Danish (Frederik Svarre)
  * Updates Desktop files (Francois Marier, Mike Manger)
- update to version 1.10.4
  * Fix gnome-shell applet for Gnome 3.12.
- update to version 1.10.3
  * Bug fixes
  - bug 1114: Closing timer window closes program.
  - bug 1120: make the GNOME shell extension compatible with GNOME 3.8
  - bug 1136: Status window always appears on startup
  - bug 1137: Make Workrave start up optional
  - bug 1146: dconf changes not honored for /org/workrave/general/operation-mode
  - bug 1147: Suspend timer during screensaver
  - bug 1148: Double deallocation causes crashes during Workrave shutdown
  - Fix Workrave icon on Unity
  - Fix size of prelude window
  - Fix size of unity indicator timebar
  - Fixed compatibility with gnome-shell 3.10
  - Allow Gnome Shell status icon to be enabled/disabled
- update to version 1.10.1
  * nothing relevant.
- update to version 1.10
  * Split "show 'postpone' and 'skip'" checkbox into two checkboxes. (Egbert Teeselink)
  * Add the capability to delete all stored statistics (Ray Satiro)
  * Workrave now offers a Gnome 3 applet. Applets for both Gnome 3
  classic and the Gnome shell are available.
  * Workrave now offers an application indicator (applet) in Unity.
  * On Unix, Workrave adds a new activity monitoring method that can be
  used instead of the XRECORD based monitoring. XRECORD monitoring
  appear be causing X crashes for some people
  (See http://issues.workrave.org/show_bug.cgi?id=1066)
  * Infrastructure update. Workrave now supports:
  - Gtk3/Gtkmm3 (only on Gnome 3; Gtk2/Gtkmm2 is still used on Gnome 2)
  - Configuration in GSettings (instead of GConf)
  - GIO based DBus (instead of freedesktop.org DBus)
  * Obsolete KDE3 support has been droppped.
  * Translation updates
  * Plus many small fixes and improvements
- remove obsolete workrave-1.9.901-gnome3-panel-makefile.patch
- remove unused workrave-kde-errors.patch
* Mon Nov  7 2011 lijewski.stefan@gmail.com
- update to version 1.9.901 (git branch):
  * correctly build on Factory (gnome3)
  * split packages for Factory
* Mon Apr 11 2011 lijewski.stefan@gmail.com
- update to version 1.9.4
- merge to only one package (without gnome and kde version)
- kde build is broken according to configure options
* Wed Feb 11 2009 sbrabec@suse.cz
- Use correct gstreamer package name.
* Thu Oct 16 2008 sbrabec@suse.cz
- Call intltoolize as last action to prevent build failures.
* Tue Sep 16 2008 ro@suse.de
- fix build regardless of libtool version
* Mon Sep  1 2008 sbrabec@suse.cz
- Updated to version 1.9.0:
  * Fixed transparency of tray icon
  * improved 64 bit support
  * exercises are now randomized
  * extended DBUS support
  * networking support can now be enabled without accepting
    incoming connections from other Workraves
  * sound has been added
* Tue Apr 29 2008 sbrabec@suse.cz
- Added Fedora patches:
  * fix locking/unlocking with gnome-screensaver (redhat#207058)
  * build with gcc-4.3
  * build GNOME applet with the latest libsigc++2
- Fixed build of KDE applet with the latest libsigc++2.
- Added desktop file.
* Mon Oct 29 2007 sbrabec@suse.cz
- Updated to version 1.8.5:
  * Task manager is never blocked by Workrave
  * Many bug fixes, the most visible ones:
  * Fixed breaks that have 'suspend timer when inactive' disabled
  * Mode menu fixed.
  * Gnome applet no longer 'hangs'.
  * Gnome applet no longer crashes Workrave.
  * Fixed 'end-of-microbreak' sound.
  * Fixed bug in multi-head support where Workrave showed multiple
    windows on a single screen.
  * Fixed locking on Gnome with xscreensaver installed
  * Polish on the applets
  * Translations updated
- Fixed gcc 4.3 errors.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Sat Aug 11 2007 mrueckert@suse.de
- switch to %%lang_package -n
- fixed typo in requires of workrave-kde
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off -lang subpackages.
* Sun Jan 28 2007 ro@suse.de
- make it build after GNOME moved to /usr
* Mon Oct 23 2006 sbrabec@suse.cz
- Updated to version 1.8.3:
  * 100%% CPU load fix.
  * GNOME screen saver support added.
  * The applet popup menu is now accessible when all timers hidden.
  * Translations updated.
  * Bug fixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 23 2005 ro@suse.de
- provide main package name in one subpackage
  (needed for debuginfo since we do not have a main package here)
* Thu Dec 15 2005 sbrabec@suse.cz
- New SuSE package, version 1.8.1.
